@@ -95,6 +95,11 @@ public class TestURLEncodedUtils {
         result = parse("price=10%20%E2%82%AC");
         Assert.assertEquals(1, result.size());
         assertNameValuePair(result.get(0), "price", "10 \u20AC");
+
+        result = parse("a=b\"c&d=e");
+        Assert.assertEquals(2, result.size());
+        assertNameValuePair(result.get(0), "a", "b\"c");
+        assertNameValuePair(result.get(1), "d", "e");
     }
 
     @Test
@@ -169,6 +174,14 @@ public class TestURLEncodedUtils {
         assertNameValuePair(result.get(0), "name", "%wa ");
     }
 
+    @Test
+    public void testEmptyQuery() throws Exception {
+        final List<NameValuePair> result = URLEncodedUtils.parse("", Consts.UTF_8);
+        Assert.assertEquals(0, result.size());
+        // [HTTPCLIENT-1889]:
+        result.add(new BasicNameValuePair("key", "value"));
+    }
+
     @Test
     public void testParseEntity() throws Exception {
         final StringEntity entity = new StringEntity("Name1=Value1");
